﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using SAP.Middleware.Connector;

namespace Excel2SapBom
{
    public partial class MainForm : Form
    {
        private Excel2SapBom.Properties.Settings settings = new Properties.Settings();

        private SapConnection sapConnection;
        private SapFunctionBase sapFunction;

        private ExcelClass excelClass;
        private Object[,] excelPositions;
        private String excelMatnr;

        public MainForm()
        {
            this.InitializeComponent();
            this.systems.DataSource = SapConnection.GetSystems;
            this.excelClass = new ExcelClass();

            SapFunctionBase.BeforeRfcFunctionCall += this.BeforeRfcFunctionCall_Handler;
            SapFunctionBase.AfterRfcFunctionCall += this.AfterRfcFunctionCall_Handler;

            this.TopMost = settings.TopMost;
            this.systems.Text = settings.System;
            this.client.Text = settings.Client;
            this.username.Text = settings.UserName;
            this.password.Text = settings.Password;

            this.Location = new Point(settings.PositionX, settings.PositionY);
        }

        ~MainForm()
        {
            ExcelClass.CloseExcel();
        }
        
        private void BeforeRfcFunctionCall_Handler(Object sender, EventArgs e)
        {
            //this.toolStripStatusSap.BackColor = Color.LawnGreen;
            this.toolStripStatusSap.Image = global::Excel2SapBom.Properties.Resources.RedLight;
            this.Refresh();
        }

        private void AfterRfcFunctionCall_Handler(Object sender, EventArgs e)
        {
            //this.toolStripStatusSap.BackColor = Color.Red;
            this.toolStripStatusSap.Image = global::Excel2SapBom.Properties.Resources.GreenLight;
            this.excelPositions = null;
            this.Refresh();
        }

        private void buttonExecute_Click(object sender, EventArgs e)
        {
            if (this.excelClass.ReadBom(ref this.excelPositions, out this.excelMatnr))
            {
                this.sapConnection = SapConnection.Factory(this.systems.Text);
                this.sapFunction = new SapFunctionSendBom(this.sapConnection.GetDestination, this.excelPositions, this.excelMatnr);
                this.sapFunction.InvokeFunction(this.client.Text, this.username.Text, this.password.Text, settings.Language);
            }
        }

        private void buttonOpenExcel_Click(object sender, EventArgs e)
        {
            ExcelClass.OpenExcel();
        }

        private void buttonCloseExcel_Click(object sender, EventArgs e)
        {
            ExcelClass.CloseExcel();
        }                     
    }
}
